StatusDocument class

Document that contains information about the history of a License Document, along with its current status and available interactions.

Constructors

StatusDocument.parse(Map<String, dynamic> json)
factory
StatusDocument.parseData(ByteData data)
factory

Properties

description → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
jsonObject → Map<String, dynamic>
final
licenseUpdated → DateTime
final
message → String
A message meant to be displayed to the User regarding the current status of the license.
final
potentialRights → PotentialRights?
Dictionary of potential rights associated with Dates.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → Status
final
statusUpdated → DateTime
final

Methods

events(EventType type) → List<Event>?
eventsWithType(String type) → List<Event>?
linkWithNoType(StatusRel rel) → Link?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
potentialRightsEndDate() → DateTime?
toString() → String
A string representation of this object.
override
url(StatusRel rel, {MediaType? preferredType, Map<String, String> parameters = const {}}) → Uri

Operators

operator ==(Object other) → bool
The equality operator.
inherited